@@ -25,7 +25,10 @@ impl Engine {
             .build_and_append_vertex_buffers(verticies.clone(), indicies.clone())?;
 
         let uniform_index = self.renderer.build_and_append_uniform_buffers(vec![
-            UniformBuffer::Matrix("Transformation Matrix", DEFAULT_MATRIX_4),
+            UniformBuffer::Matrix(
+                "Transformation Matrix",
+                uniform_type::Matrix::from_glm(DEFAULT_MATRIX_4),
+            ),
             UniformBuffer::Array("Color", settings.color),
         ])?;
 
@@ -44,7 +47,7 @@ impl Engine {
             pipeline: (
                 Pipeline {
                     vertex_buffer_index,
-                    shader_index,
+                    shader_index: shader_index,
                     texture_index: settings.texture_index,
                     uniform_index: Some(uniform_index.0),
                 },
@@ -56,9 +59,10 @@ impl Engine {
                 self.window.inner_size().height as f32,
                 0f32,
             ),
+            scale: settings.scale,
             position: (0f32, 0f32, 0f32),
             changed: false,
-            transformation_matrix: DEFAULT_MATRIX_4.to_im(),
+            transformation_matrix: DEFAULT_MATRIX_4,
             color: settings.color,
             object_index: self.objects.len(),
             camera_effect: settings.camera_effect,
@@ -69,13 +73,7 @@ impl Engine {
             object.pipeline.0,
             Some(self.renderer.append_pipeline(object.pipeline.0)?),
         );
-        object.scale(0.1, 0.1, 0.1);
-        object.resize(
-            settings.size.0,
-            settings.size.1,
-            settings.size.2,
-            self.window.inner_size(),
-        );
+        object.scale(settings.scale.0, settings.scale.1, settings.scale.2);
         object.position(
             settings.position.0,
             settings.position.1,
@@ -95,19 +93,20 @@ impl Engine {
 impl Object {
     /// Scales an object. e.g. 2.0 doubles the size and 0.5 halves
     pub fn scale(&mut self, x: f32, y: f32, z: f32) {
-        for i in self.vertices.iter_mut() {
+        /*for i in self.vertices.iter_mut() {
             i.position[0] *= x;
             i.position[1] *= y;
             i.position[2] *= z;
-        }
+        }*/
 
         self.size.0 *= x;
         self.size.1 *= y;
         self.size.2 *= z;
 
-        self.changed = true;
+        let transformation_matrix = self.transformation_matrix;
+        let result = glm::ext::scale(&transformation_matrix, glm::vec3(x, y, z));
+        self.transformation_matrix = result;
     }
-
     /// Resizes an object in pixels which are relative to the window
     pub fn resize(
         &mut self,
@@ -117,17 +116,35 @@ impl Object {
         window_size: winit::dpi::PhysicalSize<u32>,
     ) {
         let difference_in_width = if self.size.0 != 0.0 && width != 0.0 {
-            normalize(width, window_size.width) / normalize(self.size.0, window_size.width)
+            let a = normalize(width, window_size.width);
+            let b = normalize(self.size.0, window_size.width);
+            if a != 0f32 && b != 0f32 {
+                a / b
+            } else {
+                b
+            }
         } else {
             0.0
         };
         let difference_in_height = if self.size.1 != 0.0 && height != 0.0 {
-            normalize(height, window_size.height) / normalize(self.size.1, window_size.height)
+            let a = normalize(height, window_size.height);
+            let b = normalize(self.size.1, window_size.height);
+            if a != 0f32 && b != 0f32 {
+                a / b
+            } else {
+                b
+            }
         } else {
             0.0
         };
         let difference_in_depth = if self.size.2 != 0.0 && depth != 0.0 {
-            normalize(depth, window_size.width) / normalize(self.size.2, window_size.width)
+            let a = normalize(depth, window_size.width);
+            let b = normalize(self.size.2, window_size.width);
+            if a != 0f32 && b != 0f32 {
+                a / b
+            } else {
+                b
+            }
         } else {
             0.0
         };
@@ -142,7 +159,7 @@ impl Object {
     /// Rotates the object in the axis you specify
     pub fn rotate(&mut self, angle: f32, axis: RotateAxis) {
         let mut rotation_matrix = self.transformation_matrix;
-        /*rotation_matrix = glm::ext::rotate(
+        rotation_matrix = glm::ext::rotate(
             &rotation_matrix,
             angle,
             match axis {
@@ -150,7 +167,7 @@ impl Object {
                 RotateAxis::X => glm::vec3(0.0, 1.0, 0.0),
                 RotateAxis::Y => glm::vec3(1.0, 0.0, 0.0),
             },
-        );*/
+        );
         self.transformation_matrix = rotation_matrix;
 
         self.changed = true;
@@ -159,7 +176,7 @@ impl Object {
     /// Moves the object by the amount you specify in the axis you specify
     pub fn translate(&mut self, x: f32, y: f32, z: f32) {
         let mut position_matrix = self.transformation_matrix;
-        //position_matrix = glm::ext::translate(&position_matrix, glm::vec3(x, y, z));
+        position_matrix = glm::ext::translate(&position_matrix, glm::vec3(x, y, z));
         self.transformation_matrix = position_matrix;
 
         self.changed = true;
@@ -289,7 +306,7 @@ impl Object {
             .build_uniform_buffer(vec![
                 UniformBuffer::Matrix(
                     "Transformation Matrix",
-                    uniform_type::Matrix::from_im(self.transformation_matrix),
+                    uniform_type::Matrix::from_glm(self.transformation_matrix),
                 ),
                 UniformBuffer::Array("Color", self.color),
             ])?
@@ -359,7 +376,7 @@ var sampler_diffuse: sampler;"#
         let vertex_stage = format!(
             "\n// ===== VERTEX STAGE ===== //\n{}\n{}\n{}",
             r#"[[stage(vertex)]]
-fn main(input: VertexInput) -> VertexOutput {
+fn vs_main(input: VertexInput) -> VertexOutput {
     var out: VertexOutput;
     out.texture_coordinates = input.texture_coordinates;"#,
             if self.camera_effect {
@@ -375,7 +392,7 @@ fn main(input: VertexInput) -> VertexOutput {
         let fragment_stage = format!(
             "\n// ===== Fragment STAGE ===== //\n{}",
             r#"[[stage(fragment)]]
-fn main(input: VertexOutput) -> [[location(0)]] vec4<f32> {
+fn fs_main(input: VertexOutput) -> [[location(0)]] vec4<f32> {
     return textureSample(texture_diffuse, sampler_diffuse, input.texture_coordinates) * fragment_uniforms.color;
 }"#
         );
